Nobias package
===============
This package contains the implementation of the nobias library.

Audits: Demographic Parity Inspector
------------------------------------------

.. automodule:: nobias.audits
    :members:
    :undoc-members:
    :show-inheritance:

Explanations
-----------------------------------------

.. automodule:: nobias.explanation
    :members:
    :undoc-members:
    :show-inheritance:

